# OctoPrintSettingsRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**octoprint_enabled** | **bool** | Start OctoPrint service | [optional] 
**events_enabled** | **bool** | Send OctoPrint events related to print job status/progress to PrintNanny Cloud https://docs.octoprint.org/en/master/events/index.html | [optional] 
**sync_gcode** | **bool** | Sync Gcode files to/from PrintNanny Cloud | [optional] 
**sync_printer_profiles** | **bool** | Sync Printer Profiles to/from PrintNanny Cloud | [optional] 
**sync_backups** | **bool** | Upload OctoPrint backups to PrintNanny Cloud | [optional] 
**auto_backup** | **str** |  | [optional] 
**octoprint_server** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


